#[test_impl]Expand description
Run this test multiple times, replacing all references to the trait specified with a specific implementation. Use it like this:
#[test_impl(ExampleTrait = ExampleStruct, ExampleStruct2)]
#[test_impl]Run this test multiple times, replacing all references to the trait specified with a specific implementation. Use it like this:
#[test_impl(ExampleTrait = ExampleStruct, ExampleStruct2)]